@@ -4,6 +4,7 @@ use warnings;
 
 use base 'Fennec::Base::Method';
 
+use Fennec::Parser;
 use Fennec::Util::Accessors;
 use Exporter::Declare;
 use Try::Tiny;
@@ -21,8 +22,7 @@ use Time::HiRes qw/time/;
 
 Accessors qw/ workflow no_result observed created_in /;
 
-export 'tests' => sub {
-    my $name = shift;
+export 'tests' fennec {
     my %proto = @_ > 1 ? @_ : (method => shift( @_ ));
     my ( $caller, $file, $line ) = caller;
     $caller->fennec_meta->workflow->add_item(
@@ -39,11 +39,6 @@ sub init {
     $self->created_in( $$ );
 }
 
-sub lines_for_filter {
-    my $self = shift;
-    B::svref_2object( $self->method )->START->line;
-}
-
 sub run {
     my $self = shift;
     return Result->skip_testset( $self, $self->skip )
